@@ -25,6 +25,7 @@
 #include <sys/types.h>
 #include "error.h"
 #include "names.h"
+#include "uncompression.h"
 #include "checksums.h"
 #include "changes.h"
 
@@ -175,6 +176,8 @@ retvalue changes_parsefileline(const char *fileline, /*@out@*/filetype *result_t
 			type = fe_UDEB;
 		else if( p-typestart == 3 && strncmp(typestart,"log",3) == 0 )
 			type = fe_LOG;
+		else if( p-typestart == 5 && strncmp(typestart,"build",5) == 0 )
+			type = fe_LOG;
 		else {
 			fprintf(stderr, "'%s' is not .deb or .udeb!\n", filestart);
 			return RET_ERROR;
@@ -185,32 +188,30 @@ retvalue changes_parsefileline(const char *fileline, /*@out@*/filetype *result_t
 			return RET_ERROR;
 		}
 	} else {
+		enum compression c;
+		size_t l;
+
 		/* this looks like some source-package, we will have
 		 * to look for the packagetype ourself... */
 		while( *p !='\0' && !xisspace(*p) ) {
 			p++;
 		}
-		if( p-versionstart > 12 && strncmp(p-12,".orig.tar.gz",12) == 0 )
+		/* ignore compression suffix */
+		l = p - versionstart;
+		c = compression_by_suffix(versionstart, &l);
+		p = versionstart + l;
+
+		if( l > 9 && strncmp(p-9, ".orig.tar", 9) == 0 )
 			type = fe_ORIG;
-		else if( p-versionstart > 7 && strncmp(p-7,".tar.gz",7) == 0 )
+		else if( l > 4 && strncmp(p-4, ".tar", 4) == 0 )
 			type = fe_TAR;
-		else if( p-versionstart > 8 && strncmp(p-8,".diff.gz",8) == 0 )
+		else if( l > 5 && strncmp(p-5,".diff", 5) == 0 )
 			type = fe_DIFF;
-		else if( p-versionstart > 4 && strncmp(p-4,".dsc",4) == 0 )
+		else if( l > 4 && strncmp(p-4,".dsc",4) == 0 && c == c_none )
 			type = fe_DSC;
-		else if( p-versionstart > 13 && strncmp(p-13,".orig.tar.bz2",13) == 0 )
-			type = fe_ORIG;
-		else if( p-versionstart > 8 && strncmp(p-8,".tar.bz2",8) == 0 )
-			type = fe_TAR;
-		else if( p-versionstart > 9 && strncmp(p-9,".diff.bz2",9) == 0 )
-			type = fe_DIFF;
-		else if( p-versionstart > 14 && strncmp(p-14,".orig.tar.lzma",14) == 0 )
-			type = fe_ORIG;
-		else if( p-versionstart > 9 && strncmp(p-9,".tar.lzma",9) == 0 )
-			type = fe_TAR;
-		else if( p-versionstart > 10 && strncmp(p-10,".diff.lzma",10) == 0 )
-			type = fe_DIFF;
-		else if( p-versionstart > 4 && strncmp(p-4, ".log", 4) == 0 )
+		else if( l > 4 && strncmp(p-4, ".log", 4) == 0 )
+			type = fe_LOG;
+		else if( l > 6 && strncmp(p-6, ".build", 6) == 0 )
 			type = fe_LOG;
 		else {
 			type = fe_UNKNOWN;
