@@ -20,7 +20,7 @@
  * get it from the files or try to guess it.
  * if dereferencedfilekeys is != NULL, add filekeys that lost reference,
  * if tracks != NULL, update/add tracking information there... */
-retvalue changes_add(struct database *, /*@null@*/trackingdb tracks, packagetype_t packagetypeonly, component_t, architecture_t forcearchitecture, /*@null@*/const char *forcesection, /*@null@*/const char *forcepriority, struct distribution *, const char *changesfilename, int delete);
+retvalue changes_add(struct database *, /*@null@*/trackingdb tracks, const struct atomlist *packagetypes, component_t, const struct atomlist *forcearchitecture, /*@null@*/const char *forcesection, /*@null@*/const char *forcepriority, struct distribution *, const char *changesfilename, int delete);
 
 #endif
 
