@@ -27,10 +27,16 @@ struct downloaditem;
 struct downloadcache {
 	/*@null@*/struct downloaditem *items;
 	/*@null@*/struct devices *devices;
+
+	struct database *database;
+
+	/* for showing what percentage was downloaded */
+	long long size_todo, size_done;
+	unsigned int last_percent;
 };
 
 /* Initialize a new download session */
-retvalue downloadcache_initialize(struct database *,enum spacecheckmode mode,off_t reserveddb,off_t reservedother,struct downloadcache **download);
+retvalue downloadcache_initialize(enum spacecheckmode, off_t reserveddb, off_t reservedother, /*@out@*/struct downloadcache **download);
 
 /* free all memory */
 retvalue downloadcache_free(/*@null@*//*@only@*/struct downloadcache *download);
