@@ -76,8 +76,6 @@ extern struct global_config {
 	const char *logdir;
 	const char *listdir;
 	const char *morguedir;
-	/* deprecated: */
-	const char *overridedir;
 	/* flags: */
 	bool keepdirectories;
 	bool keeptemporaries;
@@ -85,6 +83,6 @@ extern struct global_config {
 	int showdownloadpercent;
 } global;
 
-enum compression { c_none, c_gzip, c_bzip2, c_lzma, c_COUNT };
+enum compression { c_none, c_gzip, c_bzip2, c_lzma, c_xz, c_COUNT };
 
 #endif
