@@ -29,7 +29,8 @@
 #include "pull.h"
 #include "upgradelist.h"
 #include "distribution.h"
-#include "terms.h"
+#include "tracking.h"
+#include "termdecide.h"
 #include "filterlist.h"
 #include "log.h"
 #include "configparser.h"
@@ -645,7 +646,7 @@ retvalue pull_prepare(struct distribution *alldistributions, struct pull_rule *r
  * decide what gets pulled                                                 *
  **************************************************************************/
 
-static upgrade_decision ud_decide_by_rule(void *privdata, const char *package, /*@null@*/const char *old_version, UNUSED(const char *new_version), const char *newcontrolchunk) {
+static upgrade_decision ud_decide_by_rule(void *privdata, const struct target *target, const char *package, /*@null@*/const char *old_version, UNUSED(const char *new_version), const char *newcontrolchunk) {
 	struct pull_rule *rule = privdata;
 	upgrade_decision decision = UD_UPGRADE;
 	retvalue r;
@@ -673,7 +674,8 @@ static upgrade_decision ud_decide_by_rule(void *privdata, const char *package, /
 	}
 
 	if( rule->includecondition != NULL ) {
-		r = term_decidechunk(rule->includecondition,newcontrolchunk);
+		r = term_decidechunktarget(rule->includecondition,
+				newcontrolchunk, target);
 		if( RET_WAS_ERROR(r) )
 			return UD_ERROR;
 		if( r == RET_NOTHING ) {
@@ -737,11 +739,6 @@ static retvalue pull_search(/*@null@*/FILE *out,struct database *database,struct
 "Warning: Override files of '%s' ignored as not yet supported while updating!\n",
 					d->distribution->codename);
 	}
-	if( d->distribution->tracking != dt_NONE ) {
-		fprintf(stderr,
-"WARNING: Pull does not yet update tracking data. Tracking data of %s will be outdated!\n",
-					d->distribution->codename);
-	}
 
 	result = RET_NOTHING;
 	for( u=d->targets ; u != NULL ; u=u->next ) {
@@ -763,22 +760,26 @@ static void pull_from_callback(void *privdata, const char **rule_p, const char *
 static retvalue pull_install(struct database *database, struct pull_distribution *distribution) {
 	retvalue result,r;
 	struct pull_target *u;
+	struct distribution *d = distribution->distribution;
 
-	assert( logger_isprepared(distribution->distribution->logger) );
+	assert( logger_isprepared(d->logger) );
 
 	result = RET_NOTHING;
 	for( u=distribution->targets ; u != NULL ; u=u->next ) {
-		r = upgradelist_install(u->upgradelist,
-				distribution->distribution->logger,
+		r = upgradelist_install(u->upgradelist, d->logger,
 				database, u->ignoredelete,
 				pull_from_callback);
-		RET_UPDATE(distribution->distribution->status, r);
+		RET_UPDATE(d->status, r);
 		RET_UPDATE(result,r);
 		upgradelist_free(u->upgradelist);
 		u->upgradelist = NULL;
 		if( RET_WAS_ERROR(r) )
 			break;
 	}
+	if( RET_IS_OK(result) && d->tracking != dt_NONE ) {
+		r = tracking_retrack(database, d, false);
+		RET_ENDUPDATE(result, r);
+	}
 	return result;
 }
 
