@@ -65,11 +65,14 @@ struct target {
 	struct table *packages;
 	/* do not allow write operations */
 	bool readonly;
+	/* was updated without tracking data (no problem when distribution
+	 * has no tracking, otherwise cause warning later) */
+	bool staletracking;
 };
 
-retvalue target_initialize_ubinary(const char *codename, component_t, architecture_t, /*@dependent@*/const struct exportmode *, bool readonly, /*@out@*/struct target **);
-retvalue target_initialize_binary(const char *codename, component_t, architecture_t, /*@dependent@*/const struct exportmode *, bool readonly, /*@out@*/struct target **);
-retvalue target_initialize_source(const char *codename, component_t, /*@dependent@*/const struct exportmode *, bool readonly, /*@out@*/struct target **);
+retvalue target_initialize_ubinary(const char *codename, component_t, architecture_t, /*@dependent@*/const struct exportmode *, bool readonly, /*@NULL@*/const char *fakecomponentprefix, /*@out@*/struct target **);
+retvalue target_initialize_binary(const char *codename, component_t, architecture_t, /*@dependent@*/const struct exportmode *, bool readonly, /*@NULL@*/const char *fakecomponentprefix, /*@out@*/struct target **);
+retvalue target_initialize_source(const char *codename, component_t, /*@dependent@*/const struct exportmode *, bool readonly, /*@NULL@*/const char *fakecomponentprefix, /*@out@*/struct target **);
 retvalue target_free(struct target *target);
 
 retvalue target_export(struct target *target, struct database *, bool onlyneeded, bool snapshot, struct release *release);
@@ -156,12 +159,12 @@ retvalue target_reoverride(struct target *, struct distribution *, struct databa
 
 retvalue package_rerunnotifiers(struct database *, struct distribution *, struct target *, const char *, const char *, void *);
 
-static inline bool target_matches(const struct target *t, component_t component, architecture_t architecture, packagetype_t packagetype) {
-	if( atom_defined(component) && component != t->component_atom )
+static inline bool target_matches(const struct target *t, const struct atomlist *components, const struct atomlist *architectures, const struct atomlist *packagetypes) {
+	if( limitations_missed(components, t->component_atom) )
 		return false;
-	if( atom_defined(architecture) && architecture != t->architecture_atom )
+	if( limitations_missed(architectures, t->architecture_atom) )
 		return false;
-	if( atom_defined(packagetype) && packagetype != t->packagetype_atom )
+	if( limitations_missed(packagetypes, t->packagetype_atom) )
 		return false;
 	return true;
 }
