@@ -322,7 +322,6 @@ stdout
 -v2=Created directory "./pool/a/t"
 -v2=Created directory "./pool/a/t/test"
 -v0*=Getting packages...
--e1*=db: 'pool/a/t/test/test_0_all.deb' added to files.db(md5sums).
 -d1*=db: 'pool/a/t/test/test_0_all.deb' added to checksums.db(pool).
 -v1*=Shutting down aptmethods...
 -v0*=Installing (and possibly deleting) packages...
@@ -383,7 +382,6 @@ stdout
 -v2=Created directory "./pool/a/t"
 -v2=Created directory "./pool/a/t/test"
 -v0*=Getting packages...
--e1*=db: 'pool/a/t/test/test_1_yyyyyyyyyy.deb' added to files.db(md5sums).
 -d1*=db: 'pool/a/t/test/test_1_yyyyyyyyyy.deb' added to checksums.db(pool).
 -v1*=Shutting down aptmethods...
 -v0*=Installing (and possibly deleting) packages...
@@ -439,7 +437,6 @@ stdout
 -v4*=  nothing to do for 'u|1234|a|x'
 -v3*=  nothing new for '1234|a|x' (use --noskipold to process anyway)
 -v0*=Getting packages...
--e1*=db: 'pool/a/t/test/fake.dsc' added to files.db(md5sums).
 -d1*=db: 'pool/a/t/test/fake.dsc' added to checksums.db(pool).
 -v1*=Shutting down aptmethods...
 -v0*=Installing (and possibly deleting) packages...
